@@ -4,8 +4,9 @@ import json
 from typing import TYPE_CHECKING, Tuple
 
 if TYPE_CHECKING:
+    from dvc_objects.fs.base import AnyFSPath, FileSystem
+
     from ._ignore import Ignore
-    from .fs.base import AnyFSPath, FileSystem
 
 
 def get_mtime_and_size(
