@@ -1,8 +1,8 @@
 from dvc_data.hashfile.db import HashFile, HashFileDB
 
 
-def test_db(tmp_upath):
-    odb = HashFileDB(tmp_upath.fs, tmp_upath)
+def test_db(tmp_upath, as_filesystem):
+    odb = HashFileDB(as_filesystem(tmp_upath.fs), tmp_upath)
 
     assert not odb.exists("123456")
     assert list(odb.all()) == []
